==> YounifyConnectSDK-Android-Sample-0.9.17.tgz: app/src/main/java/tv/younify/sdk/connectapp/YounifyDetailsFragment.kt <==
package tv.younify.sdk.connectapp

import android.annotation.SuppressLint
import android.app.AlertDialog
import android.graphics.BitmapFactory
import android.os.Build
import android.os.Bundle
import android.text.Html
import android.text.method.LinkMovementMethod
import android.util.Log
import android.view.LayoutInflater
import android.view.View
import android.view.ViewGroup
import androidx.fragment.app.Fragment
import androidx.fragment.app.activityViewModels
import androidx.lifecycle.lifecycleScope
import kotlinx.coroutines.launch
import tv.younify.sdk.connect.StreamingContent
import tv.younify.sdk.connectapp.databinding.FragmentYounifyDetailsBinding
import kotlin.coroutines.cancellation.CancellationException

private const val ARG_CONTENT = "content"

class YounifyDetailsFragment : Fragment() {
    private var _binding: FragmentYounifyDetailsBinding? = null
    private val binding get() = _binding!!

    private var streamingContent: StreamingContent? = null
    private val servicesViewModel: YounifyServicesViewModel by activityViewModels()

    override fun onCreate(savedInstanceState: Bundle?) {
        super.onCreate(savedInstanceState)
        arguments?.let {
            if (Build.VERSION.SDK_INT >= Build.VERSION_CODES.TIRAMISU) {
                streamingContent = it.getParcelable(ARG_CONTENT, StreamingContent::class.java)
            } else {
                @Suppress("DEPRECATION")
                streamingContent = it.getParcelable(ARG_CONTENT)
            }
        }
    }

    override fun onCreateView(inflater: LayoutInflater, container: ViewGroup?, savedInstanceState: Bundle?): View {
        _binding = FragmentYounifyDetailsBinding.inflate(inflater, container, false)
        return binding.root
    }

    override fun onDestroyView() {
        super.onDestroyView()
        _binding = null
    }

    override fun onStart() {
        super.onStart()

        lifecycleScope.launch {
            try {
                load()
            }
            catch (ex: CancellationException) {
                throw ex
            }
            catch (cause: Throwable) {
                AlertDialog.Builder(context)
                    .setMessage("Error: ${cause.message}")
                    .setTitle("Error")
                    .setPositiveButton("OK") { _, _ -> }
                    .create()
                    .show()
            }
        }
    }

    @SuppressLint("SetTextI18n")
    private suspend fun load() {
        val details = servicesViewModel.fetchContentDetails(streamingContent!!)

        binding.name.text = streamingContent?.title
        binding.description.text = streamingContent?.overview
        binding.duration.text = "Duration: " + streamingContent?.duration.toString()
        binding.estimatedDuration.text = "Estimated Duration: " + details?.estimatedDuration.toString()
        binding.airDate.text = "Air Date: " + streamingContent?.airDate.toString()
        binding.series.text = "Series: " + streamingContent?.series
        binding.season.text = "Season: " + streamingContent?.season
        binding.episode.text = "Episode: " + streamingContent?.episode
        binding.releaseYear.text = "Release Year: " + streamingContent?.releaseYear
        binding.contentRating.text = "Content Rating: " + streamingContent?.contentRating
        binding.watchNowUrl.text = Html.fromHtml("Watch Url: <a href=\"${streamingContent?.watchNowUrl}\">${streamingContent?.watchNowUrl}</a>", Html.FROM_HTML_MODE_LEGACY)
        binding.watchNowUrl.isClickable = true
        binding.watchNowUrl.movementMethod = LinkMovementMethod.getInstance()
        binding.tmdbID.text = "TMDB ID: " + streamingContent?.tmdbID
        binding.tmdbSeriesID.text = "TMDB Series ID: " + streamingContent?.tmdbSeriesID

        val thumbUrl = streamingContent?.largeThumbnailUrl
        if (thumbUrl != null) {
            try {
                val data = servicesViewModel.fetchImage(thumbUrl)
                if (data != null) {
                    val bmp = BitmapFactory.decodeByteArray(data, 0, data.size)
                    binding.image.setImageBitmap(bmp)
                }
            }
            catch (ex: CancellationException) {
                throw ex
            }
            catch (cause: Throwable) {
                Log.e("YounifyDetailsFragment", cause.message!!)
            }
        }

        binding.activityIndicator.visibility = View.GONE
    }
}

==> YounifyConnectSDK-Android-Sample-0.9.28.tgz: app/src/main/java/tv/younify/sdk/connectapp/YounifyDetailsFragment.kt <==
package tv.younify.sdk.connectapp

import android.annotation.SuppressLint
import android.app.AlertDialog
import android.graphics.BitmapFactory
import android.os.Build
import android.os.Bundle
import android.text.Html
import android.text.method.LinkMovementMethod
import android.util.Log
import android.view.LayoutInflater
import android.view.View
import android.view.ViewGroup
import androidx.fragment.app.Fragment
import androidx.fragment.app.activityViewModels
import androidx.lifecycle.lifecycleScope
import kotlinx.coroutines.launch
import tv.younify.sdk.connect.StreamingContent
import tv.younify.sdk.connectapp.databinding.FragmentYounifyDetailsBinding
import kotlin.coroutines.cancellation.CancellationException

private const val ARG_CONTENT = "content"

class YounifyDetailsFragment : Fragment() {
    private var _binding: FragmentYounifyDetailsBinding? = null
    private val binding get() = _binding!!

    private var streamingContent: StreamingContent? = null
    private val servicesViewModel: YounifyServicesViewModel by activityViewModels()

    override fun onCreate(savedInstanceState: Bundle?) {
        super.onCreate(savedInstanceState)
        arguments?.let {
            if (Build.VERSION.SDK_INT >= Build.VERSION_CODES.UPSIDE_DOWN_CAKE) {
                streamingContent = it.getParcelable(ARG_CONTENT, StreamingContent::class.java)
            } else {
                @Suppress("DEPRECATION")
                streamingContent = it.getParcelable(ARG_CONTENT)
            }
        }
    }

    override fun onCreateView(inflater: LayoutInflater, container: ViewGroup?, savedInstanceState: Bundle?): View {
        _binding = FragmentYounifyDetailsBinding.inflate(inflater, container, false)
        return binding.root
    }

    override fun onDestroyView() {
        super.onDestroyView()
        _binding = null
    }

    override fun onStart() {
        super.onStart()

        lifecycleScope.launch {
            try {
                load()
            }
            catch (ex: CancellationException) {
                throw ex
            }
            catch (cause: Throwable) {
                AlertDialog.Builder(context)
                    .setMessage("Error: ${cause.message}")
                    .setTitle("Error")
                    .setPositiveButton("OK") { _, _ -> }
                    .create()
                    .show()
            }
        }
    }

    @SuppressLint("SetTextI18n")
    private suspend fun load() {
        val details = servicesViewModel.fetchContentDetails(streamingContent!!)

        binding.name.text = streamingContent?.title
        binding.description.text = streamingContent?.overview
        binding.duration.text = "Duration: " + streamingContent?.duration.toString()
        binding.estimatedDuration.text = "Estimated Duration: " + details?.estimatedDuration.toString()
        binding.airDate.text = "Air Date: " + streamingContent?.airDate.toString()
        binding.series.text = "Series: " + streamingContent?.series
        binding.season.text = "Season: " + streamingContent?.season
        binding.episode.text = "Episode: " + streamingContent?.episode
        binding.releaseYear.text = "Release Year: " + streamingContent?.releaseYear
        binding.contentRating.text = "Content Rating: " + streamingContent?.contentRating
        binding.watchNowUrl.text = Html.fromHtml("Watch Url: <a href=\"${streamingContent?.watchNowUrl}\">${streamingContent?.watchNowUrl}</a>", Html.FROM_HTML_MODE_LEGACY)
        binding.watchNowUrl.isClickable = true
        binding.watchNowUrl.movementMethod = LinkMovementMethod.getInstance()
        binding.tmdbID.text = "TMDB ID: " + streamingContent?.tmdbID
        binding.tmdbSeriesID.text = "TMDB Series ID: " + streamingContent?.tmdbSeriesID

        val thumbUrl = streamingContent?.largeThumbnailUrl
        if (thumbUrl != null) {
            try {
                val data = servicesViewModel.fetchImage(thumbUrl)
                if (data != null) {
                    val bmp = BitmapFactory.decodeByteArray(data, 0, data.size)
                    binding.image.setImageBitmap(bmp)
                }
            }
            catch (ex: CancellationException) {
                throw ex
            }
            catch (cause: Throwable) {
                Log.e("YounifyDetailsFragment", cause.message!!)
            }
        }

        binding.activityIndicator.visibility = View.GONE
    }
}
